@@ -21,7 +21,7 @@
 #' @importFrom Biostrings DNAStringSet
 #' @importFrom Biostrings width
 #' @importFrom Biostrings nmismatch
-#' @importFrom Biostrings pairwiseAlignment
+#' @importFrom pwalign pairwiseAlignment
 #' @importFrom seqinr read.alignment
 #' @importFrom seqinr as.alignment
 #' @importFrom seqinr consensus
@@ -249,7 +249,7 @@ vqscustompct <- function(fasta, method= c("conbase", "domhapbase"), samplingfirs
     Mfe <- MutationFreq(dst)
     Pie <- NucleotideDiversity(dst)
     #Abundance-based (frequency)
-    nm <- nmismatch(pairwiseAlignment(hapre$seqs,hapre$seqs[1]))
+    nm <- nmismatch(pwalign::pairwiseAlignment(hapre$seqs,hapre$seqs[1]))
     Mfm <- MutationFreqVar(nm,hapre$nr,len=width(hapre$seqs)[1])
     Pim <- NucleotideDiversity(dst,hapre$nr)
 
@@ -451,7 +451,7 @@ vqscustompct <- function(fasta, method= c("conbase", "domhapbase"), samplingfirs
     Mfe <- MutationFreq(dst)
     Pie <- NucleotideDiversity(dst)
     #Abundance-based (frequency)
-    nm <- nmismatch(pairwiseAlignment(hapre$seqs,hapre$seqs[1]))
+    nm <- nmismatch(pwalign::pairwiseAlignment(hapre$seqs,hapre$seqs[1]))
     Mfm <- MutationFreqVar(nm,hapre$nr,len=width(hapre$seqs)[1])
     Pim <- NucleotideDiversity(dst,hapre$nr)
 
